---
name: New step request
about: Suggest a new step/package manager to update
title: ''
type: Feature
labels: request step
assignees: ''

---

## Checklist

- [ ] I have searched the issue tracker for relevant or duplicate issues.

## I want to suggest a new step

* Which tool is this about? Where is its repository?
* Which operating systems are supported by this tool?
* What should Topgrade do to figure out if the tool needs to be invoked?
* Which exact commands should Topgrade run?
* Does it have a `--dry-run` option? i.e., print what should be done and exit
* Does it need the user to confirm the execution? And does it provide a `--yes`
  option to skip this?

## More information

<!-- Assuming that someone else implements the step,
please state if you know how to test it from a side branch of Topgrade. -->

- [ ] I am able and willing to implement this step myself
